package com.yeejoin.amos.api.tool.controller;

import com.yeejoin.amos.api.tool.face.model.ViewModel;
import com.yeejoin.amos.api.tool.face.service.ViewService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.web.bind.annotation.*;
import org.typroject.tyboot.core.foundation.enumeration.UserType;
import org.typroject.tyboot.core.restful.doc.TycloudOperation;
import org.typroject.tyboot.core.restful.doc.TycloudResource;
import org.typroject.tyboot.core.restful.utils.ResponseHelper;
import org.typroject.tyboot.core.restful.utils.ResponseModel;

import javax.annotation.Resource;
import java.util.List;

@RestController
@TycloudResource(module = "iot", value = "view")
@RequestMapping(value = "/v1/iot/View")
@Api(tags = "测试")
public class ViewController {
    private final Logger logger = LogManager.getLogger(ViewController.class);

    @Resource
    private ViewService viewService;

    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @ApiOperation(value = "根据所属机构查询")
    @GetMapping("/list")
    public ResponseModel selectForList(@RequestParam(value = "agency") String agency) {
        return ResponseHelper.buildResponse(viewService.queryForAViewList(agency));
    }

    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @PostMapping("/save")
    @ApiOperation(value = "新增",notes = "新增")
    public ResponseModel<ViewModel> save(@RequestBody ViewModel viewModel){
        viewModel = viewService.createWithModel(viewModel);
        return ResponseHelper.buildResponse(viewModel);
    }
    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @PostMapping("/sences/list")
    @ApiOperation(value = "根据场景查询")
    public ResponseModel selectByScene(@RequestParam(value = "sences") String sences){
        return ResponseHelper.buildResponse(viewService.queryByScene(sences));
    }

    /**
     * 根据字段查询
     */
    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @PostMapping ("/select/all")
    @ApiOperation(value = "查询大全")
    public ResponseModel query(@RequestParam(value = "sences") String sences,@RequestParam(value = "miniSences") String miniSences){
        return ResponseHelper.buildResponse(viewService.query(sences,miniSences));
    }

    /**
     * 查询所有
     */
    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @PostMapping("/every")
    @ApiOperation("平台")
    public ResponseModel<List<ViewModel>> queryEvery(){
        return ResponseHelper.buildResponse(viewService.queryEvery());
    }

    /**
     * 根据ID删除
     */
    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @PostMapping("/delete")
    @ApiOperation(value = "删除")
    public ResponseModel<Boolean> deleteById(@RequestParam(value = "SEQUENCE_NBR") Long SEQUENCE_NBR){
        return ResponseHelper.buildResponse(viewService.deleteBySeq(SEQUENCE_NBR));
    }
    /**
     * 根据ID更新
     */
    @TycloudOperation(ApiLevel = UserType.SUPER_ADMIN,needAuth = false)
    @PostMapping("/update")
    @ApiOperation(value = "更新")
    public ResponseModel updateById(@RequestParam(value = "SEQUENCE_NBR") Long SEQUENCE_NBR){
        return ResponseHelper.buildResponse(viewService.updateTimes(SEQUENCE_NBR));
    }
}
